@@ -7,7 +7,7 @@
 
  Collection of auxiliary functions
 
- Copyright (C) 2001 -- 2004 Martin Schlather, 
+ Copyright (C) 2001 -- 2005 Martin Schlather, 
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -25,35 +25,11 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 
-
 #include <math.h>
 #include <unistd.h>
 #include <assert.h>
 #include "auxiliary.h"
-#include <Rgraphics.h>
- 
-void pid(int *i)  {
-#ifndef Unix  
-  *i = getpid();
-#else
-  *i = 0; 
-#endif
-}
 
-void xyInchToPixels(double *xy, double *Pixels) {
-  DevDesc* dd;
-  dd = CurrentDevice();
-  Pixels[0] = GConvertXUnits(xy[0], INCHES, DEVICE, dd);
-  Pixels[1] = GConvertYUnits(xy[1], INCHES, DEVICE, dd);
-}
-
-void hostname(char **h, int *i){
-#ifdef Unix  
-  gethostname(*h, *i);
-#else
-  *h[0]=0;
-#endif
-}  
 
 void I0ML0(double *x, int *n) {
   int i;
@@ -179,112 +155,6 @@ double struve(double x, double nu, double factor_sign, bool expscaled)
   return res;
 }
 
-
-
-void RandomPermutation(double *x, int n, double *y ) {
-  /* calculates a random permutation of the n-vector x and returns it in y */
-  double *pos;
-  int *sort,j;
-  
-  sort = (int*) malloc(sizeof(int)*n);
-  pos = (double*) malloc(sizeof(double)*n);
-  GetRNGstate();
-  for (j=0;j<n;j++) {  
-    pos[j]=UNIFORM_RANDOM;
-    sort[j]=j; 
-  }
-  PutRNGstate();
-  orderdouble(pos,sort,0,n-1);
-  for (j=0;j<n;j++) y[j] = x[sort[j]]; 
-  free(sort);
-  free(pos);
-}
-
-
-void orderdouble(double *d, int *pos, int start, int end)
-     /* quicksort algorithm, slightly modified:
-        does not sort the data, but d[pos] will be ordered 
-	NOTE: pos must have the values 0,1,2,...,start-end !
-	(orderdouble is a kind of sorting pos according to
-	the variable d)
-     */
-{
-  int randpos, pivot, left, right, pivotpos, swap;
-  double Dpivot;
-
-  if( start < end )
-  {   
-    //GetRNGstate();randpos = start + (int) (UNIFORM_RANDOM * (end-start+1)); PutRNGstate();
-    randpos = (int) (0.5 * (start + end));
-    pivot = pos[randpos];
-    pos[randpos] = pos[start];
-    pos[start] = pivot;
-    Dpivot = d[pivot];
-   
-    pivotpos=start; 
-    left = start;
-    right=end+1;   
-
-    while (left < right) {      
-      while (++left < right && d[pos[left]] < Dpivot) pivotpos++;
-      while (--right > left && d[pos[right]] > Dpivot) ;      
-      if (left < right) {
-        swap=pos[left]; pos[left]=pos[right]; pos[right]=swap;
-        pivotpos++;
-      }
-    }
-    pos[start] = pos[pivotpos];
-    pos[pivotpos] = pivot;
-    orderdouble( d, pos, start, pivotpos-1);
-    orderdouble( d, pos, pivotpos + 1, end);
-  }
-}
-
-
-void quicksortdouble(double *d, int start, int end) {
-  int i=start, j=end;
-  double h, x=d[(start+end)/2];
-  do {    
-    while (d[i]<x) i++; 
-    while (d[j]>x) j--;
-    if (i<=j)
-      {
-	h=d[i]; d[i]=d[j]; d[j]=h;
-	i++; j--;
-      }
-  } while (i<=j);
-  if (start<j) quicksortdouble(d, start, j);
-  if (i<end) quicksortdouble(d, i, end);
-}
-
-
-// the next function should be obsolete (soon)!
-#define EPSILON_QUANTILE 0.00000001
-double quantile(double *X, int lb, double p) 
-{
-  int *pos,i,j; 
-  double result,*Y;
-  assert( (pos = (int *) malloc(sizeof(int) * lb)) != NULL);
-  assert( (Y = (double *) malloc(sizeof(double) * lb)) != NULL);
-  for (j=i=0; i<lb; i++) { 
-    if (!(RF_ISNA(X[i]))) {
-      pos[j] = j; /* needed for orderdouble */  
-      Y[j] = X[i];
-      j++;
-    }
-  }
-  if (j==0) {free(pos); free(Y); return RF_NAN;}
-  orderdouble(Y, pos, 0, j-1);  
-  
-  result = Y[pos[(int) (p * (double) j + EPSILON_QUANTILE)]];
-  free(pos);
-  free(Y);
-  return result;
-} 
-void Rquantile(double *X,int *lb,double *p, double *res) { *res = quantile(X,*lb,*p); }
-
-
-
 void vectordist(double *v, int *Dim, double *dist, int *diag){
   int m, n, d, l, dim, r, lr, dr, add;
   add = (*diag==0) ? 1 : 0;
